@@ -94,7 +94,7 @@ class PrestoViewMetadataExtractor(Extractor):
         row = self._alchemy_extractor.extract()
         while row:
             columns = self._get_column_metadata(row['view_original_text'])
-            yield TableMetadata(database='presto',
+            yield TableMetadata(database='hive',
                                 cluster=self._cluster,
                                 schema=row['schema'],
                                 name=row['name'],
