@@ -102,8 +102,8 @@ class FileSystem(Scoped):
         """
         metadata_dict = self._dask_fs.info(path)
 
-        # for key, val in metadata_dict.items():
-        #     LOGGER.info(f'{str(key)} {str(val)}')
+        for key, val in metadata_dict.items():
+            LOGGER.info(f'{str(key)} {str(val)}')
 
         # Checking for last updated not found
         last_updated_key = self._metadata_key_mapping[FileSystem.LAST_UPDATED]
